==> Phidgetlinux_2.1.5.20081023.tar.gz: Phidgetlinux/phidget21/cphidgetsbc.c <==
#include "stdafx.h"
#include "cphidgetsbc.h"
#include "cphidget.h"
#include "cthread.h"
#include "cphidgetlist.h"
#include "csocket.h"

//PhidgetSBCManager

//Private
void CPhidgetSBCManager_free(void *arg)
{
	CPhidgetSBCManagerHandle sbcm = (CPhidgetSBCManagerHandle)arg;
	
	if(!sbcm) return;
	free(sbcm); sbcm = NULL;
	return;
}

//Public
int CCONV CPhidgetSBCManager_create(CPhidgetSBCManagerHandle *sbcm)
{
	CPhidgetSBCManagerHandle sbcmtemp = 0;
	
	TESTPTR(sbcm)
	if(!(sbcmtemp = (CPhidgetSBCManagerHandle)malloc(sizeof(CPhidgetSBCManager))))
		return EPHIDGET_NOMEMORY;
	ZEROMEM(sbcmtemp, sizeof(CPhidgetSBCManager));
	
	*sbcm = sbcmtemp;
	return EPHIDGET_OK;
}

int CCONV CPhidgetSBCManager_stop(CPhidgetSBCManagerHandle sbcm)
{
	TESTPTR(sbcm)

	if(sbcm->state == PHIDGETMANAGER_ACTIVE)
	{
		sbcm->state = PHIDGETMANAGER_INACTIVE;
		CThread_mutex_lock(&serverLock);
		unregisterSBCManager(sbcm);
		CThread_mutex_unlock(&serverLock);
	}

	return EPHIDGET_OK;
}

int CCONV CPhidgetSBCManager_delete(CPhidgetSBCManagerHandle sbcm)
{
	CPhidgetSBCManager_free(sbcm);
	return EPHIDGET_OK;
}

int CCONV CPhidgetSBCManager_set_OnAttach_Handler(CPhidgetSBCManagerHandle sbcm, int (CCONV *fptr)(CPhidgetSBCHandle sbc, void *userPtr), void *userPtr)
{
	TESTPTR(sbcm)
	sbcm->fptrAttachChange = fptr; 
	sbcm->fptrAttachChangeptr = userPtr; 
	return EPHIDGET_OK; 
}

int CCONV CPhidgetSBCManager_set_OnDetach_Handler(CPhidgetSBCManagerHandle sbcm, int (CCONV *fptr)(CPhidgetSBCHandle sbc, void *userPtr), void *userPtr)
{
	TESTPTR(sbcm)
	sbcm->fptrDetachChange = fptr; 
	sbcm->fptrDetachChangeptr = userPtr; 
	return EPHIDGET_OK; 
}

int CCONV CPhidgetSBCManager_set_OnError_Handler(CPhidgetSBCManagerHandle sbcm, 
	int(CCONV *fptr)(CPhidgetSBCManagerHandle, void *, int, const char *), void *userPtr)
{
	TESTPTR(sbcm)
	sbcm->fptrError = fptr;
	sbcm->fptrErrorptr = userPtr;
	return EPHIDGET_OK;
}

int CCONV CPhidgetSBCManager_getAttachedSBCs(CPhidgetSBCManagerHandle sbcm, CPhidgetSBCHandle *sbcArray[], int *count)
{

	TESTPTRS(sbcArray, count)
	TESTPTR(sbcm)

	return EPHIDGET_UNSUPPORTED; 
}


//PhidgetSBC

//Private
int CCONV CPhidgetSBC_areExtraEqual(void *arg1, void *arg2)
{
	CPhidgetSBCHandle sbc1 = (CPhidgetSBCHandle)arg1;
	CPhidgetSBCHandle sbc2 = (CPhidgetSBCHandle)arg2;
	
	TESTPTRS(sbc1, sbc2)
	
	if(!strcmp(sbc1->mac, sbc2->mac) 
	   && !strcmp(sbc1->fversion, sbc2->fversion) 
	   && sbc1->hversion == sbc2->hversion)
		return PTRUE;
	return PFALSE;
}

int CCONV CPhidgetSBC_areEqual(void *arg1, void *arg2)
{
	CPhidgetSBCHandle sbc1 = (CPhidgetSBCHandle)arg1;
	CPhidgetSBCHandle sbc2 = (CPhidgetSBCHandle)arg2;
	
	TESTPTRS(sbc1, sbc2)
		
	if(!strcmp(sbc1->mac, sbc2->mac))
		return PTRUE;
	return PFALSE;
}

void CCONV CPhidgetSBC_free(void *arg)
{
	CPhidgetSBCHandle sbc = (CPhidgetSBCHandle)arg;
	if (!sbc)
		return;

	CPhidgetRemote_free(sbc->networkInfo);

	free(sbc); sbc = NULL;
	return;
}

//Public
int CCONV CPhidgetSBC_create(CPhidgetSBCHandle *sbc)
{
	CPhidgetSBCHandle sbctemp = 0;
	
	TESTPTR(sbc)
	if(!(sbctemp = (CPhidgetSBCHandle)malloc(sizeof(CPhidgetSBC))))
		return EPHIDGET_NOMEMORY;
	ZEROMEM(sbctemp, sizeof(CPhidgetSBC));
	
	*sbc = sbctemp;
	return EPHIDGET_OK;
}

int CCONV CPhidgetSBC_delete(CPhidgetSBCHandle sbc)
{
	CPhidgetSBC_free(sbc); sbc = NULL;
	return EPHIDGET_OK;
}

int CCONV CPhidgetSBC_getFirmwareVersion(CPhidgetSBCHandle sbc, const char **version)
{
	TESTPTRS(sbc, version)

	*version = (char *)sbc->fversion;
	return EPHIDGET_OK;
}

int CCONV CPhidgetSBC_getHardwareVersion(CPhidgetSBCHandle sbc, int *version)
{
	TESTPTRS(sbc, version)

	*version = sbc->hversion;
	return EPHIDGET_OK;
}

int CCONV CPhidgetSBC_getMacAddress(CPhidgetSBCHandle sbc, const char **mac)
{
	TESTPTRS(sbc, mac)

	*mac = (char *)sbc->mac;
	return EPHIDGET_OK;
}


int CCONV CPhidgetSBC_getAddress(CPhidgetSBCHandle sbc, const char **ipAddr)
{
	TESTPTRS(sbc, ipAddr)
	if (!sbc->networkInfo)
		return EPHIDGET_NETWORK_NOTCONNECTED;
	if(!sbc->networkInfo->mdns) //not mdns
	{
		return EPHIDGET_UNEXPECTED;
	}
#ifdef USE_ZEROCONF
	if(getZeroconfHostPort(sbc->networkInfo))
		return EPHIDGET_NETWORK;
	if(!sbc->networkInfo->zeroconf_host)
	{
		return EPHIDGET_NETWORK;
	}
	*ipAddr = (char *)sbc->networkInfo->zeroconf_host;
	return EPHIDGET_OK;
#else
	return EPHIDGET_UNEXPECTED;
#endif
}

==> Phidgetlinux_2.1.5.20090105.tar.gz: Phidgetlinux/phidget21/cphidgetsbc.c <==
#include "stdafx.h"
#include "cphidgetsbc.h"
#include "cphidget.h"
#include "cthread.h"
#include "cphidgetlist.h"
#include "csocket.h"

//PhidgetSBCManager

//Private
void CPhidgetSBCManager_free(void *arg)
{
	CPhidgetSBCManagerHandle sbcm = (CPhidgetSBCManagerHandle)arg;
	
	if(!sbcm) return;
	free(sbcm); sbcm = NULL;
	return;
}

//Public
int CCONV CPhidgetSBCManager_create(CPhidgetSBCManagerHandle *sbcm)
{
	CPhidgetSBCManagerHandle sbcmtemp = 0;
	
	TESTPTR(sbcm)
	if(!(sbcmtemp = (CPhidgetSBCManagerHandle)malloc(sizeof(CPhidgetSBCManager))))
		return EPHIDGET_NOMEMORY;
	ZEROMEM(sbcmtemp, sizeof(CPhidgetSBCManager));

	*sbcm = sbcmtemp;
	return EPHIDGET_OK;
}

int CCONV CPhidgetSBCManager_stop(CPhidgetSBCManagerHandle sbcm)
{
	TESTPTR(sbcm)

	if(sbcm->state == PHIDGETMANAGER_ACTIVE)
	{
		sbcm->state = PHIDGETMANAGER_INACTIVE;
		unregisterSBCManager(sbcm);
	}

	return EPHIDGET_OK;
}

int CCONV CPhidgetSBCManager_delete(CPhidgetSBCManagerHandle sbcm)
{
	CPhidgetSBCManager_free(sbcm);
	return EPHIDGET_OK;
}

int CCONV CPhidgetSBCManager_set_OnAttach_Handler(CPhidgetSBCManagerHandle sbcm, int (CCONV *fptr)(CPhidgetSBCHandle sbc, void *userPtr), void *userPtr)
{
	TESTPTR(sbcm)
	sbcm->fptrAttachChange = fptr; 
	sbcm->fptrAttachChangeptr = userPtr; 
	return EPHIDGET_OK; 
}

int CCONV CPhidgetSBCManager_set_OnDetach_Handler(CPhidgetSBCManagerHandle sbcm, int (CCONV *fptr)(CPhidgetSBCHandle sbc, void *userPtr), void *userPtr)
{
	TESTPTR(sbcm)
	sbcm->fptrDetachChange = fptr; 
	sbcm->fptrDetachChangeptr = userPtr; 
	return EPHIDGET_OK; 
}

int CCONV CPhidgetSBCManager_set_OnError_Handler(CPhidgetSBCManagerHandle sbcm, 
	int(CCONV *fptr)(CPhidgetSBCManagerHandle, void *, int, const char *), void *userPtr)
{
	TESTPTR(sbcm)
	sbcm->fptrError = fptr;
	sbcm->fptrErrorptr = userPtr;
	return EPHIDGET_OK;
}

int CCONV CPhidgetSBCManager_getAttachedSBCs(CPhidgetSBCManagerHandle sbcm, CPhidgetSBCHandle *sbcArray[], int *count)
{

	TESTPTRS(sbcArray, count)
	TESTPTR(sbcm)

	return EPHIDGET_UNSUPPORTED; 
}


//PhidgetSBC

//Private
int CCONV CPhidgetSBC_areExtraEqual(void *arg1, void *arg2)
{
	CPhidgetSBCHandle sbc1 = (CPhidgetSBCHandle)arg1;
	CPhidgetSBCHandle sbc2 = (CPhidgetSBCHandle)arg2;
	
	TESTPTRS(sbc1, sbc2)
	
	if(!strcmp(sbc1->mac, sbc2->mac) 
	   && !strcmp(sbc1->fversion, sbc2->fversion) 
	   && sbc1->hversion == sbc2->hversion
	   && !strcmp(sbc1->hostname?sbc1->hostname:"", sbc2->hostname?sbc2->hostname:""))
		return PTRUE;
	return PFALSE;
}

int CCONV CPhidgetSBC_areEqual(void *arg1, void *arg2)
{
	CPhidgetSBCHandle sbc1 = (CPhidgetSBCHandle)arg1;
	CPhidgetSBCHandle sbc2 = (CPhidgetSBCHandle)arg2;
	
	TESTPTRS(sbc1, sbc2)
		
	if(!strcmp(sbc1->mac, sbc2->mac))
		return PTRUE;
	return PFALSE;
}

void CCONV CPhidgetSBC_free(void *arg)
{
	CPhidgetSBCHandle sbc = (CPhidgetSBCHandle)arg;
	if (!sbc)
		return;

	CPhidgetRemote_free(sbc->networkInfo);

	free(sbc); sbc = NULL;
	return;
}

//Public
int CCONV CPhidgetSBC_create(CPhidgetSBCHandle *sbc)
{
	CPhidgetSBCHandle sbctemp = 0;
	
	TESTPTR(sbc)
	if(!(sbctemp = (CPhidgetSBCHandle)malloc(sizeof(CPhidgetSBC))))
		return EPHIDGET_NOMEMORY;
	ZEROMEM(sbctemp, sizeof(CPhidgetSBC));
	
	// Version 1 doesn't support hostname variable
	sbctemp->txtver = 1;

	*sbc = sbctemp;
	return EPHIDGET_OK;
}

int CCONV CPhidgetSBC_delete(CPhidgetSBCHandle sbc)
{
	CPhidgetSBC_free(sbc); sbc = NULL;
	return EPHIDGET_OK;
}

int CCONV CPhidgetSBC_getFirmwareVersion(CPhidgetSBCHandle sbc, const char **version)
{
	TESTPTRS(sbc, version)

	*version = (char *)sbc->fversion;
	return EPHIDGET_OK;
}

int CCONV CPhidgetSBC_getHardwareVersion(CPhidgetSBCHandle sbc, int *version)
{
	TESTPTRS(sbc, version)

	*version = sbc->hversion;
	return EPHIDGET_OK;
}

int CCONV CPhidgetSBC_getMacAddress(CPhidgetSBCHandle sbc, const char **mac)
{
	TESTPTRS(sbc, mac)

	*mac = (char *)sbc->mac;
	return EPHIDGET_OK;
}

int CCONV CPhidgetSBC_getHostname(CPhidgetSBCHandle sbc, const char **hostname)
{
	TESTPTRS(sbc, hostname)

	if(sbc->txtver >= 2)
	{
		refreshZeroconfSBC(sbc);
		*hostname = (char *)sbc->hostname;
		return EPHIDGET_OK;
	}
	else
	{
		*hostname = NULL;
		return EPHIDGET_UNSUPPORTED;
	}
}

int CCONV CPhidgetSBC_getAddress(CPhidgetSBCHandle sbc, const char **ipAddr)
{
	TESTPTRS(sbc, ipAddr)
	if (!sbc->networkInfo)
		return EPHIDGET_NETWORK_NOTCONNECTED;
	if(!sbc->networkInfo->mdns) //not mdns
	{
		return EPHIDGET_UNEXPECTED;
	}
#ifdef USE_ZEROCONF
	if(getZeroconfHostPort(sbc->networkInfo))
		return EPHIDGET_NETWORK;
	if(!sbc->networkInfo->zeroconf_host)
	{
		return EPHIDGET_NETWORK;
	}
	*ipAddr = (char *)sbc->networkInfo->zeroconf_host;
	return EPHIDGET_OK;
#else
	return EPHIDGET_UNEXPECTED;
#endif
}
